summaryrefslogtreecommitdiff
path: root/cmake
diff options
context:
space:
mode:
authorAllen Winter <allen.winter@kdab.com>2017-06-03 17:01:10 -0400
committerAllen Winter <allen.winter@kdab.com>2017-06-03 17:01:10 -0400
commit910aa8066a26e192dfc6042fd40634bdb8d80c25 (patch)
tree3f4d1513d36dbd690da43a35f7e87839f7b5b040 /cmake
parent2a5d9b0b63863d036ee2519f69a4a917f7cfbdd7 (diff)
downloadlibical-git-910aa8066a26e192dfc6042fd40634bdb8d80c25.tar.gz
s/GObjectIntrospection/INTROSPECTION/g
Diffstat (limited to 'cmake')
-rw-r--r--cmake/modules/FindGObjectIntrospection.cmake46
-rw-r--r--cmake/modules/GObjectIntrospectionMacros.cmake8
2 files changed, 27 insertions, 27 deletions
diff --git a/cmake/modules/GObjectIntrospectionMacros.cmake b/cmake/modules/GObjectIntrospectionMacros.cmake
index 33e2c0f9..0f9a386b 100644
--- a/cmake/modules/GObjectIntrospectionMacros.cmake
+++ b/cmake/modules/GObjectIntrospectionMacros.cmake
@@ -51,8 +51,8 @@ macro(gir_add_introspections introspections_girs)
add_custom_command(
COMMAND ${CMAKE_COMMAND} -E env "CC='${CMAKE_C_COMPILER}'"
- ${INTROSPECTION_SCANNER}
- ${INTROSPECTION_SCANNER_ARGS}
+ ${GObjectIntrospection_SCANNER}
+ ${GObjectIntrospection_SCANNER_ARGS}
--namespace=${_gir_namespace}
--nsversion=${_gir_version}
${_gir_libtool}
@@ -76,8 +76,8 @@ macro(gir_add_introspections introspections_girs)
string(REPLACE ".gir" ".typelib" _typelib "${gir}")
add_custom_command(
- COMMAND ${INTROSPECTION_COMPILER}
- ${INTROSPECTION_COMPILER_ARGS}
+ COMMAND ${GObjectIntrospection_COMPILER}
+ ${GObjectIntrospection_COMPILER_ARGS}
--includedir=.
${CMAKE_CURRENT_BINARY_DIR}/${gir}
-o ${CMAKE_CURRENT_BINARY_DIR}/${_typelib}
diff --git a/cmake/modules/FindGObjectIntrospection.cmake b/cmake/modules/FindGObjectIntrospection.cmake
index 2073c3cb..eb014bb4 100644
--- a/cmake/modules/FindGObjectIntrospection.cmake
+++ b/cmake/modules/FindGObjectIntrospection.cmake
@@ -2,14 +2,14 @@
#
# Once done this will define
#
# INTROSPECTION_FOUND - system has gobject-introspection
# INTROSPECTION_SCANNER - the gobject-introspection scanner, g-ir-scanner
# INTROSPECTION_COMPILER - the gobject-introspection compiler, g-ir-compiler
# INTROSPECTION_GENERATE - the gobject-introspection generate, g-ir-generate
# INTROSPECTION_GIRDIR
# INTROSPECTION_TYPELIBDIR
# INTROSPECTION_CFLAGS
# INTROSPECTION_LIBS
#
# Copyright (C) 2010, Pino Toscano, <pino@kde.org>
#
@@ -39,23 +39,23 @@ if(PKG_CONFIG_FOUND)
endif()
pkg_check_modules(_pc_gir gobject-introspection-1.0${_gir_version_cmp})
if(_pc_gir_FOUND)
- set(INTROSPECTION_FOUND TRUE)
- _gir_get_pkgconfig_var(INTROSPECTION_SCANNER "g_ir_scanner")
- _gir_get_pkgconfig_var(INTROSPECTION_COMPILER "g_ir_compiler")
- _gir_get_pkgconfig_var(INTROSPECTION_GENERATE "g_ir_generate")
- _gir_get_pkgconfig_var(INTROSPECTION_GIRDIR "girdir")
- _gir_get_pkgconfig_var(INTROSPECTION_TYPELIBDIR "typelibdir")
- set(INTROSPECTION_CFLAGS "${_pc_gir_CFLAGS}")
- set(INTROSPECTION_LIBS "${_pc_gir_LIBS}")
+ set(GObjectIntrospection_FOUND TRUE)
+ _gir_get_pkgconfig_var(GObjectIntrospection_SCANNER "g_ir_scanner")
+ _gir_get_pkgconfig_var(GObjectIntrospection_COMPILER "g_ir_compiler")
+ _gir_get_pkgconfig_var(GObjectIntrospection_GENERATE "g_ir_generate")
+ _gir_get_pkgconfig_var(GObjectIntrospection_GIRDIR "girdir")
+ _gir_get_pkgconfig_var(GObjectIntrospection_TYPELIBDIR "typelibdir")
+ set(GObjectIntrospection_CFLAGS "${_pc_gir_CFLAGS}")
+ set(GObjectIntrospection_LIBS "${_pc_gir_LIBS}")
endif()
endif()
mark_as_advanced(
- INTROSPECTION_SCANNER
- INTROSPECTION_COMPILER
- INTROSPECTION_GENERATE
- INTROSPECTION_GIRDIR
- INTROSPECTION_TYPELIBDIR
- INTROSPECTION_CFLAGS
- INTROSPECTION_LIBS
+ GObjectIntrospection_SCANNER
+ GObjectIntrospection_COMPILER
+ GObjectIntrospection_GENERATE
+ GObjectIntrospection_GIRDIR
+ GObjectIntrospection_TYPELIBDIR
+ GObjectIntrospection_CFLAGS
+ GObjectIntrospection_LIBS
)
@@ -2,14 +2,14 @@
# Once done this will define
#
-# INTROSPECTION_FOUND - system has gobject-introspection
-# INTROSPECTION_SCANNER - the gobject-introspection scanner, g-ir-scanner
-# INTROSPECTION_COMPILER - the gobject-introspection compiler, g-ir-compiler
-# INTROSPECTION_GENERATE - the gobject-introspection generate, g-ir-generate
-# INTROSPECTION_GIRDIR
-# INTROSPECTION_TYPELIBDIR
-# INTROSPECTION_CFLAGS
-# INTROSPECTION_LIBS
+# GObjectIntrospection_FOUND - system has gobject-introspection
+# GObjectIntrospection_SCANNER - the gobject-introspection scanner, g-ir-scanner
+# GObjectIntrospection_COMPILER - the gobject-introspection compiler, g-ir-compiler
+# GObjectIntrospection_GENERATE - the gobject-introspection generate, g-ir-generate
+# GObjectIntrospection_GIRDIR
+# GObjectIntrospection_TYPELIBDIR
+# GObjectIntrospection_CFLAGS
+# GObjectIntrospection_LIBS
#
# Copyright (C) 2010, Pino Toscano, <pino@kde.org>